Part II. Reference

# XMLRésuméLibrary: User Guide

About this chapter | XML Résumé Library User Guide | Element Reference

# Reference

Table of Contents

I. Element Reference
  academics - Container for information about academic experience
  achievement - An accomplishment made at a job
  achievements - Container for one or more job achievements
  address - A postal address
  annotation - Additional information about a degree
  artTitle - A title of an article or other work
  author - An author of a publication
  award - An award or other honor
  awards - Container for one or more awards
  birth - Container for information about a person's birth
  bookTitle - A title of a book or similar work
  break - A linebreak (Deprecated)
  citation - The name of a work being referenced
  city - The name of a city
  clearance - A security clearance
  clearances - One or more security clearances
  company - The name of a company (Deprecated)
  contact - Container for one or more methods of contacting someone
  copyright - A copyright notice
  country - A country name
  county - A county name
  date - A specific instant in time
  dayOfMonth - An ordinal day of the month
  degree - Container for information about a degree or similar certification
  degrees - Container for one or more degrees
  description - An explanation of something
  docpath - (Deprecated)
  email - An e-mail address
  emphasis - An emphasized block of text
  employer - A name of an employer
  fax - A fax telephone number
  firstname - A person's given name
  from - The beginning point in a period of time
  gpa - Information about a grade point average
  head - (Deprecated)
  header - Container for information about the person being described in a résumé
  history - Container for a person's previous (and possibly current) jobs
  instantMessage - An instant message username or address
  institution - A name of an academic institution
  interest - Something a person is interested in
  interests - Container for one or more interests
  job - A specific employment engagement
  jobtitle - A job title
  keyword - A keyword to be used for résumé indexing and searching
  keywords - Container for a list of keywords
  label - (Deprecated)
  lastModified - Information about when a résumé was last modified
  legalnotice - A legal statement
  level - A degree type
  link - A titled hyperlink
  location - A location, with city-level granularity
  major - A main course of study
  membership - A professional membership
  memberships - Container for one or more memberships
  middlenames - One or more middle names of a person
  minor - A minor course of study
  misc - Miscellaneous remarks
  month - A month name
  name - A person's name
  node - (Deprecated)
  note - Additional information
  objective - A person's employment goal
  organization - A name of an organization
  pageNums - One or more page numbers or ranges
  pager - A pager telephone number
  para - A paragraph of text
  period - A period of time
  phone - A voice telephone number
  possible - The highest possible score in a GPA
  postalCode - A postal code
  prefecture - A name of a prefecture or other administrative district
  present - Indicates the current time
  project - Container for information about a project
  projects - Container for one or more projects
  province - A name or abbreviation of a province
  pub - A work published by the résumé owner
  pubDate - The date a work was published (Deprecated)
  publisher - Information about a publisher of a work
  pubs - A group of one or more publications
  referee - Someone who can provide additional information about the person the résumé describes
  referees - Contains one or more referees
  result - An outcome of a subject
  resume - A résumé or curriculum vitae
  resumes - A collection of one or more résumés
  score - The score earned in a GPA
  skill - A name and/or description of a skill
  skillarea - A group of broadly related skill sets
  skillareas - Group of one or more skill areas (Deprecated)
  skills - Group of one or more skills (Deprecated)
  skillset - A titled group of one or more related skills
  state - A name or abbreviation of a state
  street - A street name, number, and other related information
  street2 - A second line of a street address (Deprecated)
  subject - A name of a class or topic of study
  subjects - A group of one or more subjects
  suburb - A name of a suburb
  suffix - A suffix of a name, usually specifying lineage
  surname - A family name
  tail - (Deprecated)
  title - A title or heading
  to - The ending point in a period of time
  uri - A Uniform Resource Indicator (Deprecated)
  url - A Uniform Resource Locator
  ward - A name of a division of a city, town, or county
  year - A year
  zip - A zip code
II. XSL Parameter Reference
  address.format - controls default formatting of the address element
  css.href - indicates the CSS stylesheet to use to format HTML output
  header.format - controls formatting of the header element
  interest.description.format - controls formatting of interest descriptions
  referees.display - Determines whether or not referees are visible in formatted output
  skills.format - controls formatting of the skillset element
  skills.level.display - Determines whether or not skill level attributes are visible in formatted output
  subjects.format - controls formatting of the subjects element
3. CSS Class Reference
  Overview

About this chapter | XML Résumé Library User Guide | Element Reference